package com.ynet.life.sujrb.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.life.base.LifeAction;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.file.LifeFile;
import com.ynet.life.file.parser.CommonFileParserInterface;
import com.ynet.life.file.parser.CommonParserFactory;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Random;
import java.util.StringTokenizer;

/* loaded from: com_ynet_life_sujrb_action.jar:com/ynet/life/sujrb/action/ReportDownloadAction.class */
public class ReportDownloadAction extends LifeAction {
    private static final String FIELD_SEPERATOR = "||";
    protected String fileTypeField;
    protected String fileNameField;
    protected String titleField;
    protected String encoding;
    private List outputFields;
    private List outputFormats;
    private List titles;
    private String iCollName;

    public String execute(Context ctx) throws GENEException {
        try {
            ctx.terminate();
            List recordList = initFromContext(ctx, this.iCollName);
            String fileType = (String) ctx.get(this.fileTypeField);
            CommonFileParserInterface parser = CommonParserFactory.createParser(fileType);
            String filePathName = getFileName(fileType, this.fileNameField);
            String language = getLanguage(ctx);
            List titlesI18N = new ArrayList();
            if (this.titles != null) {
                for (int i = 0; i < this.titles.size(); i++) {
                    titlesI18N.add(LifeStandard.getResouceDisplayAt((String) this.titles.get(i), language));
                }
            }
            parser.writeToFile(titlesI18N, recordList, this.outputFields, this.outputFormats, filePathName, this.encoding, this.titleField);
            ctx.put("downloadFile", filePathName);
            return "0";
        } catch (Exception ex) {
            Trace.logError("LifeAction", "RZPT90001:报表下载处理出错", ex);
            throw new TranFailException("RZPT90001", "报表下载处理出错", false);
        }
    }

    private String getLanguage(Context context) {
        if (context == null) {
            return null;
        }
        String language = null;
        try {
            language = (String) context.getDataValue("session_language");
        } catch (GENEException unused) {
        }
        return language;
    }

    protected String getFileName(String fileType, String fileName) throws TranFailException {
        String rootPath = LifeStandard.getSelfDefineSettingsValue("tempDownloadDir");
        String folder = String.valueOf(LifeStandard.getServerTime("yyyyMMdd")) + LifeFile.DIR_SEPARATOR;
        LifeFile.makeMultiDirectory(rootPath, folder);
        String filePathName = String.valueOf(LifeStandard.getServerTime("HHmmssSSS")) + new Random().nextInt(1000) + fileName + '.' + fileType;
        return String.valueOf(rootPath) + folder + filePathName;
    }

    public List initFromContext(Map context, String iCollName) throws TranFailException {
        List recordList = new ArrayList();
        for (Map kcoll : (List) context.get(iCollName)) {
            recordList.add(kcoll);
        }
        return recordList;
    }

    public void setOutputFields(String outputFields) {
        List result = new ArrayList();
        StringTokenizer toke = new StringTokenizer(outputFields, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            result.add(input);
        }
        this.outputFields = result;
    }

    public void setOutputFormats(String outputFormats) {
        List result = new ArrayList();
        StringTokenizer toke = new StringTokenizer(outputFormats, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            result.add(input);
        }
        this.outputFormats = result;
    }

    public void setTitles(String titles) {
        List title = new ArrayList();
        StringTokenizer toke = new StringTokenizer(titles, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            title.add(input);
        }
        this.titles = title;
    }

    public void setICollName(String collName) {
        this.iCollName = collName;
    }

    public void setFileTypeField(String fileTypeField) {
        this.fileTypeField = fileTypeField;
    }

    public void setTitleField(String titleField) {
        this.titleField = titleField;
    }

    public void setFileNameField(String fileNameField) {
        this.fileNameField = fileNameField;
    }

    public void setEncoding(String encoding) {
        this.encoding = encoding;
    }
}
